.. _contributors:

Contributors
==============

Contributors are the authors who started the development of BioServices
(and authors of this reference on `BioInformatics <http://bioinformatics.oxfordjournals.org/content/29/24/3241>`_). 

In addition to the main authors of the papers the following developers have
implemented modules now available in BioServices:

 * Achilles Rasquinha implemented the BiGG models service :class:`bioservices.bigg` module
 * Sven-Maurice Althoff, Christian Knauth implemented the :class:`bioservices.muscle` module.
 * Patrick Short implemented the :class:`bioservices.clinvitae` module

And thank you also to the contributions from users who have sent communication
via emails or via the `ticket system <https://github.com/cokelaer/bioservices/issues>`_.

Special thanks to Thoba Lose (https://github.com/thobalose) and
https://github.com/jsmusach for various pull requests.

Note that originally code (and earlier tickets) were hosted  `elsewhere <https://www.assembla.com/spaces/bioservices/tickets>`_.
